Fix spelling errors

Project: http://git-wip-us.apache.org/repos/asf/flume/repo
Commit: http://git-wip-us.apache.org/repos/asf/flume/commit/c6f619a6
Tree: http://git-wip-us.apache.org/repos/asf/flume/tree/c6f619a6
Diff: http://git-wip-us.apache.org/repos/asf/flume/diff/c6f619a6

Branch: refs/heads/FLUME-1787
Commit: c6f619a6c52530d84e0d942a771b01060a50d397
Parents: 4c953da
Author: Brock Noland <[email protected]>
Authored: Thu Dec 20 10:33:29 2012 -0600
Committer: Brock Noland <[email protected]>
Committed: Thu Dec 20 10:33:29 2012 -0600

----------------------------------------------------------------------
 dev-support/test-patch.py |   13 +++----------
 1 files changed, 3 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flume/blob/c6f619a6/dev-support/test-patch.py
----------------------------------------------------------------------
diff --git a/dev-support/test-patch.py b/dev-support/test-patch.py
index 1b1db3c..789d59c 100755
--- a/dev-support/test-patch.py
+++ b/dev-support/test-patch.py
@@ -46,7 +46,7 @@ def jira_get_defect(result, defect, username, password):
 
 def jira_post_comment(result, defect, branch, username, password):
   url = "%s/rest/api/2/issue/%s/comment" % (BASE_JIRA_URL, defect)
-  body = [ "Here are the results of testing the latest attachement " ]
+  body = [ "Here are the results of testing the latest attachment" ]
   body += [ "%s against %s." % (result.attachment, branch) ]
   body += [ "" ]
   if result._fatal:
@@ -85,7 +85,7 @@ def jira_post_comment(result, defect, branch, username, 
password):
     print "FATAL: %s" % (msg)
     sys.exit(1)
 
 # hack (from hadoop) but REST api doesn't list attachements?
 def jira_get_attachments(result, defect, username, password):
   html = jira_get_defect_html(result, defect, username, password)
   pattern = "(/secure/attachment/[0-9]+/%s[0-9\-]*\.(patch|txt|patch\.txt))" % 
(re.escape(defect))
@@ -264,7 +264,7 @@ if options.defect:
     sys.exit(1)
   attachments = jira_get_attachments(result, defect, username, password)
   if not attachments:
-    print "ERROR: No attachements found for %s" % (defect)
+    print "ERROR: No attachments found for %s" % (defect)
     sys.exit(1)
   result.attachment = attachments.pop()
   patch_contents = jira_request(result, result.attachment, username, password, 
None, {}).read()
@@ -285,10 +285,3 @@ else:
   result.info.append("patch applied and built but tests did not execute")
 
 result.exit_handler()
-
-#import readline # optional, will allow Up/Down/History in the console
-#import code
-#vars = globals().copy()
-#vars.update(locals())
-#shell = code.InteractiveConsole(vars)
-#shell.interact()
@@ -85,7 +85,7 @@ def jira_post_comment(result, defect, branch, username, 
     sys.exit(1)
 
-# hack (from hadoop) but REST api doesn't list attachements?
+# hack (from hadoop) but REST api doesn't list attachments?
 def jira_get_attachments(result, defect, username, password):
   html = jira_get_defect_html(result, defect, username, password)

Reply via email to